@@ -41,9 +41,7 @@ class Object
 
   def must_be( eq )
     unless self == eq then
-      stos = self.to_s; stos = stos[0,15] + '...' if stos.size > 15
-      etos = eq.to_s;   etos = etos[0,15] + '...' if etos.size > 15
-      raise ArgumentError, "arg #{stos}(#{type}) is not #{etos}"
+      raise ArgumentError, "arg #{inspect}(#{type}) is not #{eq.inspect}"
     end
     self
   end
