@@ -5,7 +5,7 @@
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
-#   the GNU Lesser General Public License version 2 or later.
+#   the GNU General Public License version 2 or later.
 #
 
 require 'amstd/must'
@@ -19,10 +19,13 @@ class VersionNumber
 
   def initialize( maj, min = nil, tee = nil )
     if String === maj then
-      maj, min, tee = maj.scan( VERSION_EXP )[0]
-      maj = maj.to_i if maj
-      min = min.to_i if min
-      tee = tee.to_i if tee
+      unless m = VERSION_EXP.match( maj ) then
+        raise ArgumentError, "wrong version string format '#{maj}'"
+      end
+      maj = m[1]; min = m[2]; tee = m[3]
+      maj = maj.to_i
+      min = min.to_i unless min.empty?
+      tee = tee.to_i unless tee.empty?
     end
     maj.must Integer
     if min then
