@@ -5,25 +5,26 @@
 
 require 'tmail/tmail'
 
-t = TMail.loadfrom( 'm3.txt' )
+mail = TMail::Mail.loadfrom( ARGV[0] || 'm/multipart' )
 
 puts '-------------- multipart mail parsing test -----------------'
 puts
 
 puts '========= preamble =============='
-puts t.body
+print mail.body
 puts
 
 puts '========== parts ================'
-t.parts.each_with_index do |i,idx|
+mail.parts.each_with_index do |i,idx|
   puts "<#{idx+1}>"
-  puts i.body
+  print mail.body
   puts
 end
 
 puts '========= epilogue =============='
-puts t.epilogue
+print mail.epilogue
+puts
 
-
-print "\n========= re-struct =============\n\n"
-puts t.to_s
+puts "========= re-struct ============="
+print mail.decoded
+puts
